/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: ReservationCreateClient.java 36 2011-06-20 14:38:41Z dangtran $
 *
 */

package org.ow2.sirocco.cloudmanager.api.tools;

import java.util.Calendar;
import java.util.GregorianCalendar;

import com.beust.jcommander.Parameter;
import org.ow2.sirocco.cloudmanager.api.spec.ReservationSpec;
import org.ow2.sirocco.cloudmanager.api.spec.UserAPI;

public class ReservationCreateClient extends Client {

    @Parameter(names = "-projectId", description = "identifier of the project.", required = true)
    private String projectId;

    @Parameter(names = "-startTime", description = "startTime (e.g., 2011-04-16-00:00).", required = true)
    private String startTime;

    @Parameter(names = "-endTime", description = "endTime (e.g., 2011-04-17-23:59).", required = true)
    private String endTime;

    @Parameter(names = "-numberOfCPUCore", description = "number of CPU core(s) to reserve.", required = true)
    private String numberOfCPUCore;

    @Parameter(names = "-memorySizeInMB", description = "memory size in MB to reserve.", required = true)
    private String memorySizeInMB;

    @Parameter(names = "-storageSizeInMB", description = "storage size in MB to reserve.", required = true)
    private String storageSizeInMB;

    @Parameter(names = "-hypervisorType", description = "type of hypervisor.", required = true)
    private String hypervisorType;

    @Parameter(names = "-location", description = "location.", required = true)
    private String location;

    public ReservationCreateClient() {
        this.commandName = "sirocco-reservation-create";
    }

    @Override
    protected Object getOptions() {
        return this;
    }

    @Override
    protected void operation(final UserAPI proxy) throws Exception {
        ReservationSpec reservationSpec = new ReservationSpec();

        reservationSpec.setProjectId(this.projectId);

        // Parse startTime
        Integer startYear = new Integer(this.startTime.substring(0, 4));
        Integer startMonth = new Integer(this.startTime.substring(5, 7));
        // Because Month is a 0-based value in Calendar !
        if (startMonth == 0) {
            // nothing to do.
        } else {
            startMonth = startMonth - 1;
        }
        Integer startDay = new Integer(this.startTime.substring(8, 10));
        Integer startHour = new Integer(this.startTime.substring(11, 13));
        Integer startMinute = new Integer(this.startTime.substring(14, 16));
        Calendar startTime_Calendar = new GregorianCalendar();
        startTime_Calendar.set(startYear, startMonth, startDay, startHour, startMinute, 0);
        reservationSpec.setStartTime(startTime_Calendar);

        // Parse endTime
        Integer endYear = new Integer(this.endTime.substring(0, 4));
        Integer endMonth = new Integer(this.endTime.substring(5, 7));
        // Because Month is a 0-based value in Calendar !
        if (endMonth == 0) {
            // nothing to do.
        } else {
            endMonth = endMonth - 1;
        }
        Integer endDay = new Integer(this.endTime.substring(8, 10));
        Integer endHour = new Integer(this.endTime.substring(11, 13));
        Integer endMinute = new Integer(this.endTime.substring(14, 16));
        Calendar endTime_Calendar = new GregorianCalendar();
        endTime_Calendar.set(endYear, endMonth, endDay, endHour, endMinute, 0);
        reservationSpec.setEndTime(endTime_Calendar);

        reservationSpec.setNumberOfCPUCore(new Integer(this.numberOfCPUCore));
        reservationSpec.setMemorySizeInMB(new Integer(this.memorySizeInMB));
        reservationSpec.setStorageSizeInMB(new Integer(this.storageSizeInMB));
        reservationSpec.setHypervisorType(this.hypervisorType);
        reservationSpec.setLocation(this.location);

        Integer result = proxy.reserveResources(reservationSpec);
        System.out.println("reserve done: reservationId: " + result);
    }

    public static void main(final String[] args) {
        new ReservationCreateClient().run(args);
    }

}
